package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Feb 17, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Content struct {
URL string `json:"url"`
Title string `json:"title"`
Paragraphs []string `json:"paragraphs"`
FetchedAt time.Time `json:"fetchedAt"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.